@@ -223,6 +223,20 @@ public enum PGProperty {
       false,
       new String[] {"select", "callIfNoReturn", "call"}),
 
+  /**
+   * Group startup parameters in a transaction
+   * This is important in pool-by-transaction scenarios in order to make sure that all the statements
+   * reaches the same connection that is being initialized. All of the startup parameters will be wrapped
+   * in a transaction
+   * Note this is off by default as pgbouncer in statement mode
+   */
+  GROUP_STARTUP_PARAMETERS(
+      "groupStartupParameters",
+      "false",
+      "This is important in pool-by-transaction scenarios in order to make sure that all "
+          + "the statements reaches the same connection that is being initialized."
+  ),
+
   GSS_ENC_MODE(
       "gssEncMode",
       "allow",
@@ -292,6 +306,15 @@ public enum PGProperty {
       "false",
       "If disabled hosts are connected in the given order. If enabled hosts are chosen randomly from the set of suitable candidates"),
 
+  /**
+   * <p>If this is set then the client side will bind to this address. This is useful if you need
+   * to choose which interface to connect to.</p>
+   */
+  LOCAL_SOCKET_ADDRESS(
+      "localSocketAddress",
+      null,
+      "Local Socket address, if set bind the client side of the socket to this address"),
+
   /**
    * This property is no longer used by the driver and will be ignored.
    * Logging is configured via java.util.logging.
@@ -684,7 +707,7 @@ public enum PGProperty {
       "any",
       "Specifies what kind of server to connect",
       false,
-      new String [] {"any", "primary", "master", "slave", "secondary",  "preferSlave", "preferSecondary"}),
+      new String [] {"any", "primary", "master", "slave", "secondary",  "preferSlave", "preferSecondary", "preferPrimary"}),
 
   /**
    * Enable or disable TCP keep-alive. The default is {@code false}.
@@ -696,8 +719,8 @@ public enum PGProperty {
 
   TCP_NO_DELAY(
       "tcpNoDelay",
-      "false",
-      "Enable or disable TCP no delay. The default is (@code false}."
+      "true",
+      "Enable or disable TCP no delay. The default is (@code true}."
   ),
   /**
    * Specifies the length to return for types of unknown length.
@@ -742,7 +765,6 @@ public enum PGProperty {
   private final boolean required;
   private final String description;
   private final String /* @Nullable */ [] choices;
-  private final boolean deprecated;
 
   PGProperty(String name, /* @Nullable */ String defaultValue, String description) {
     this(name, defaultValue, description, false);
@@ -759,11 +781,6 @@ public enum PGProperty {
     this.required = required;
     this.description = description;
     this.choices = choices;
-    try {
-      this.deprecated = PGProperty.class.getField(name()).getAnnotation(Deprecated.class) != null;
-    } catch (NoSuchFieldException e) {
-      throw new RuntimeException(e);
-    }
   }
 
   private static final Map<String, PGProperty> PROPS_BY_NAME = new HashMap<String, PGProperty>();
@@ -822,15 +839,6 @@ public enum PGProperty {
     return choices;
   }
 
-  /**
-   * Returns whether this connection parameter is deprecated.
-   *
-   * @return whether this connection parameter is deprecated
-   */
-  public boolean isDeprecated() {
-    return deprecated;
-  }
-
   /**
    * Returns the value of the connection parameters according to the given {@code Properties} or the
    * default value.
