@@ -1015,6 +1015,26 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
     PGProperty.ASSUME_MIN_SERVER_VERSION.set(properties, minVersion);
   }
 
+  /**
+   * This is important in pool-by-transaction scenarios in order to make sure that all the statements
+   * reaches the same connection that is being initialized. If set then we will group the startup
+   * parameters in a transaction
+   * @return whether to group starup parameters or not
+   * @see PGProperty#GROUP_STARTUP_PARAMETERS
+   */
+  public boolean getGroupStartupParameters() {
+    return PGProperty.GROUP_STARTUP_PARAMETERS.getBoolean(properties);
+  }
+
+  /**
+   *
+   * @param groupStartupParameters whether to group startup Parameters in a transaction or not
+   * @see PGProperty#GROUP_STARTUP_PARAMETERS
+   */
+  public void setGroupStartupParameters(boolean groupStartupParameters) {
+    PGProperty.GROUP_STARTUP_PARAMETERS.set(properties, groupStartupParameters);
+  }
+
   /**
    * @return JAAS application name
    * @see PGProperty#JAAS_APPLICATION_NAME
@@ -1207,6 +1227,22 @@ public abstract class BaseDataSource implements CommonDataSource, Referenceable
     return PGProperty.REPLICATION.get(properties);
   }
 
+  /**
+   * @return the localSocketAddress
+   * @see PGProperty#LOCAL_SOCKET_ADDRESS
+   */
+  public /* @Nullable */ String getLocalSocketAddress() {
+    return PGProperty.LOCAL_SOCKET_ADDRESS.get(properties);
+  }
+
+  /**
+   * @param localSocketAddress local address to bind client side to
+   * @see PGProperty#LOCAL_SOCKET_ADDRESS
+   */
+  public void setLocalSocketAddress( String localSocketAddress ) {
+    PGProperty.LOCAL_SOCKET_ADDRESS.set(properties,localSocketAddress);
+  }
+
   /**
    * This property is no longer used by the driver and will be ignored.
    * @return loggerLevel in properties
