@@ -69,6 +69,7 @@ import java.time.LocalDate;
 import java.time.LocalDateTime;
 import java.time.LocalTime;
 import java.time.OffsetDateTime;
+import java.time.OffsetTime;
 import java.util.ArrayList;
 import java.util.Calendar;
 import java.util.Map;
@@ -94,11 +95,25 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
 
     this.preparedQuery = query;
     this.preparedParameters = this.preparedQuery.query.createParameterList();
+    int parameterCount = preparedParameters.getParameterCount();
+    int maxSupportedParameters = maximumNumberOfParameters();
+    if (parameterCount > maxSupportedParameters) {
+      throw new PSQLException(
+          GT.tr("PreparedStatement can have at most {0} parameters. Please consider using arrays, or splitting the query in several ones, or using COPY. Given query has {1} parameters",
+              maxSupportedParameters,
+              parameterCount),
+          PSQLState.INVALID_PARAMETER_VALUE);
+    }
+
     // TODO: this.wantsGeneratedKeysAlways = true;
 
     setPoolable(true); // As per JDBC spec: prepared and callable statements are poolable by
   }
 
+  final int maximumNumberOfParameters() {
+    return connection.getPreferQueryMode() == PreferQueryMode.SIMPLE ? Integer.MAX_VALUE : 65535;
+  }
+
   @Override
   public ResultSet executeQuery(String sql) throws SQLException {
     throw new PSQLException(
@@ -614,6 +629,9 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
           } else if (in instanceof LocalTime) {
             setTime(parameterIndex, (LocalTime) in);
             break;
+          } else if (in instanceof OffsetTime) {
+            setTime(parameterIndex, (OffsetTime) in);
+            break;
           } else {
             tmpt = getTimestampUtils().toTime(getDefaultCalendar(), in.toString());
           }
@@ -988,6 +1006,8 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
       setDate(parameterIndex, (LocalDate) x);
     } else if (x instanceof LocalTime) {
       setTime(parameterIndex, (LocalTime) x);
+    } else if (x instanceof OffsetTime) {
+      setTime(parameterIndex, (OffsetTime) x);
     } else if (x instanceof LocalDateTime) {
       setTimestamp(parameterIndex, (LocalDateTime) x);
     } else if (x instanceof OffsetDateTime) {
@@ -1439,6 +1459,11 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     bindString(i, getTimestampUtils().toString(localTime), oid);
   }
 
+  private void setTime(/* @Positive */ int i, OffsetTime offsetTime) throws SQLException {
+    int oid = Oid.TIMETZ;
+    bindString(i, getTimestampUtils().toString(offsetTime), oid);
+  }
+
   private void setTimestamp(/* @Positive */ int i, LocalDateTime localDateTime)
       throws SQLException {
     int oid = Oid.TIMESTAMP;
@@ -1680,7 +1705,7 @@ class PgPreparedStatement extends PgStatement implements PreparedStatement {
     final int highestBlockCount = 128;
     final int maxValueBlocks = bindCount == 0 ? 1024 /* if no binds, use 1024 rows */
         : Integer.highestOneBit( // deriveForMultiBatch supports powers of two only
-            Math.min(Math.max(1, (Short.MAX_VALUE - 1) / bindCount), highestBlockCount));
+            Math.min(Math.max(1, maximumNumberOfParameters() / bindCount), highestBlockCount));
     int unprocessedBatchCount = batchParameters.size();
     final int fullValueBlocksCount = unprocessedBatchCount / maxValueBlocks;
     final int partialValueBlocksCount = Integer.bitCount(unprocessedBatchCount % maxValueBlocks);
